==> apache-geode-native-1.13.8-src.tgz: apache-geode-native-1.13.8-src/cppcache/src/LRULocalDestroyAction.hpp <==
#pragma once

#ifndef GEODE_LRULOCALDESTROYACTION_H_
#define GEODE_LRULOCALDESTROYACTION_H_

/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <atomic>

#include <geode/internal/geode_globals.hpp>

#include "LRUAction.hpp"
#include "MapEntry.hpp"
#include "RegionInternal.hpp"

namespace apache {
namespace geode {
namespace client {

/**
 * @brief LRUAction for localDestroy.
 */
class APACHE_GEODE_EXPORT LRULocalDestroyAction : public virtual LRUAction {
 private:
  RegionInternal* m_regionPtr;
  LRUEntriesMap* m_entriesMapPtr;

  LRULocalDestroyAction(RegionInternal* regionPtr, LRUEntriesMap* entriesMapPtr)
      : m_regionPtr(regionPtr), m_entriesMapPtr(entriesMapPtr) {
    m_destroys = true;
  }

 public:
  virtual ~LRULocalDestroyAction() {}

  virtual bool evict(const std::shared_ptr<MapEntryImpl>& mePtr);

  virtual LRUAction::Action getType() { return LRUAction::LOCAL_DESTROY; }
  friend class LRUAction;
};
}  // namespace client
}  // namespace geode
}  // namespace apache

#endif  // GEODE_LRULOCALDESTROYACTION_H_

==> apache-geode-native-1.15.2-src.tgz: apache-geode-native-1.15.2-src/cppcache/src/LRULocalDestroyAction.hpp <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#ifndef GEODE_LRULOCALDESTROYACTION_H_
#define GEODE_LRULOCALDESTROYACTION_H_

#include <atomic>

#include <geode/internal/geode_globals.hpp>

#include "LRUAction.hpp"
#include "MapEntry.hpp"
#include "RegionInternal.hpp"

namespace apache {
namespace geode {
namespace client {

/**
 * @brief LRUAction for localDestroy.
 */
class LRULocalDestroyAction : public virtual LRUAction {
 private:
  RegionInternal* m_regionPtr;
  LRUEntriesMap* m_entriesMapPtr;

  LRULocalDestroyAction(RegionInternal* regionPtr, LRUEntriesMap* entriesMapPtr)
      : m_regionPtr(regionPtr), m_entriesMapPtr(entriesMapPtr) {
    m_destroys = true;
  }

 public:
  ~LRULocalDestroyAction() noexcept override = default;

  bool evict(const std::shared_ptr<MapEntryImpl>& mePtr) override;

  LRUAction::Action getType() override { return LRUAction::LOCAL_DESTROY; }
  friend class LRUAction;
};

}  // namespace client
}  // namespace geode
}  // namespace apache

#endif  // GEODE_LRULOCALDESTROYACTION_H_
